/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.model.enumerator;

import java.io.Serializable;
import java.util.Arrays;
import java.util.Comparator;

public enum EventType implements Serializable
{
    // Unknown Event
    UNKNOWN("UNKNOWN", "Unknown event"),

    // User Events
    USER_LOGIN("USER_LOGIN", "User logged in"), USER_LOGOUT("USER_LOGOUT", "User logged out"), USER_CREATE(
        "USER_CREATE", "User created"), USER_DELETE("USER_DELETE", "User deleted"), USER_MODIFY(
        "USER_MODIFY", "User modified"), ENTERPRISE_CREATE("ENTERPRISE_CREATE",
        "Enterprise created"), ENTERPRISE_MODIFY("ENTERPRISE_MODIFY", "Enterprise modified"), ENTERPRISE_DELETE(
        "ENTERPRISE_DELETE", "Enterprise deleted"),

    // Virtual Infrastructure Events
    VM_POWERON("VM_POWERON", "Started virtual machine"), VM_PAUSED("VM_PAUSED",
        "Paused virtual machine"), VM_RESUMED("VM_RESUMED", "Resumed virtual machine"), VM_POWEROFF(
        "VM_POWEROFF", "Stopped virtual machine"), VM_DESTROY("VM_DESTROY",
        "Destroyed virtual machine"), VM_MOVED("VM_MOVED", "Virtual machine moved"), VM_CHECK_HEALTH(
        "VIRTUAL_MACHINE_HEALTH_STATE", "Virtual machine checked"), VDC_CREATE("VDC_CREATE",
        "Created virtual datacenter"), VDC_MODIFY("VDC_MODIFY", "Modified virtual datacenter"), VDC_DELETE(
        "VDC_DELETE", "Deleted virtual datacenter"), VAPP_CREATE("VAPP_CREATE",
        "Created virtual appliance"), VAPP_MODIFY("VAPP_MODIFY", "Modified virtual appliance"), VAPP_DELETE(
        "VAPP_DELETE", "Deleted virtual appliance"), VAPP_POWERON("VAPP_POWERON",
        "Deployed virtual appliance"), VAPP_POWEROFF("VAPP_POWEROFF",
        "Undeployed virtual appliance"), VAPP_MOVE("VAPP_MOVE", "Virtual appliance moved"), VAPP_COPY(
        "VAPP_COPY", "Virtual appliance copied"), VM_CREATE("VM_CREATE", "Created virtual machine"), VM_DELETE(
        "VM_DELETE", "Deleted virtual machine"), VM_UNDEPLOY("VM_UNDEPLOY",
        "Undeploy virtual machine"), VM_DEPLOY("VM_DEPLOY", "Deploy virtual machine"), VM_STATE(
        "VM_STATE", "Apply state virtual machine"), VM_RECONFIGURE("VM_RECONFIGURE",
        "Reconfigure virtual machine"), VM_INSTANCE("VM_INSTANCE", "Instance virtual machine"), VM_JOB(
        "VM_JOB", "Common job for virtual machine"), VM_TASK("VM_TASK",
        "Common task for virtual machine"), VM_REFRESH_RESOURCES("VM_REFRESH_RESOURCES",
        "Refresh virtual machine resources"),

    // Infrastructure Events
    DC_CREATE("DC_CREATE", "Datacenter created"), DC_MODIFY("DC_MODIFY", "Datacenter modified"), DC_DELETE(
        "DC_DELETE", "Datacenter deleted"), RACK_CREATE("RACK_CREATE", "Rack created"), RACK_MODIFY(
        "RACK_MODIFY", "Rack modified"), RACK_DELETE("RACK_DELETE", "Rack deleted"), RACK_VLAN_POOL(
        "RACK_VLAN_POOL", "VLAN pool exceeded in rack"), MACHINE_CREATE("MACHINE_CREATE",
        "Physical machine created"), MACHINE_MODIFY("MACHINE_MODIFY", "Physical machine modified"), MACHINE_DELETE(
        "MACHINE_DELETE", "Physical machine deleted"), MACHINE_CHECK("MACHINE_CHECK",
        "Physical machine checked"), MACHINE_RETRIEVE_VMS("MACHINE_RETRIEVE_VMS",
        "Virtual machines discovered on physical machine"), MACHINE_CREATED_RETRIEVED_VMS(
        "MACHINE_CREATED_RETRIEVED_VMS", "Retrieved virtual machines from physical machine"), MACHINE_DELETE_VMS_NOTMANAGED(
        "MACHINE_DELETE_VMS_NOTMANAGED",
        "Deleted virtual machines that were retrieved but not captured"), REMOTE_SERVICES_CREATE(
        "REMOTE_SERVICES_CREATE", "Remote service created"), REMOTE_SERVICES_UPDATE(
        "REMOTE_SERVICE_UPDATE", "Remote service updated"), REMOTE_SERVICES_CHECK(
        "REMOTE_SERVICES_CHECK", "Remote service checked"), REMOTE_SERVICES_DELETE(
        "REMOTE_SERVICES_DELETE", "Remote service deleted"), REMOTE_SERVICES_ERROR(
        "REMOTE_SERVICES_ERROR", "Remote service error"), REMOTE_SERVICES_SUCCESS(
        "REMOTE_SERVICES_SUCCESS", "Remote services successful creation"), RACK_RETRIEVAL(
        "RACK_RETRIEVAL", "Retrieve rack"), APPLIANCE_MANAGER_CONFIGURATION(
        "APPLIANCE_MANAGER_CONFIGURATION_", "The appliance manager is not properly configured"),

    // Storage System Events
    POOL_CREATE("POOL_CREATE", "Storage Pool created"), POOL_MODIFY("POOL_MODIFY",
        "Storage pool modified"), POOL_DELETE("POOL_DELETE", "Storage pool deleted"), VOLUME_CREATE(
        "VOLUME_CREATE", "Volume created"), VOLUME_MODIFY("VOLUME_MODIFY", "Volume modified"), VOLUME_DELETE(
        "VOLUME_DELETE", "Volume deleted"), VOLUME_ATTACH("VOLUME_ATTACH", "Volume attached"), VOLUME_DETACH(
        "VOLUME_DETACH", "Volume detached"), VOLUME_MOVED("VOLUME_MOVED", "Volume moved"), HARD_DISK_CREATE(
        "HARD_DISK_CREATE", "Hard disk created"), HARD_DISK_DELETE("HARD_DISK_DELETE",
        "Hard disk deleted"), HARD_DISK_ASSIGN("HARD_DISK_ASSIGN", "Hard disk assigned"), HARD_DISK_UNASSIGN(
        "HARD_DISK_UNASSIGN", "Hard disk unassigned"),

    // Virtual Machine Template Events
    VI_DOWNLOAD("VI_DOWNLOAD", "Virtual machine template download from a remote repository"), VI_PROMOTE(
        "VI_PROMOTE", "Promoted virtual machine template instance "), VI_ADD("VI_ADD",
        "Virtual machine template added to the appliance library"), VI_DELETE("VI_DELETE",
        "Virtual machine template deleted from the appliance library"), DISK_CONVERSION(
        "DISK_CONVERSION", "Disk conversion started"), RAW_IMPORT_CONVERSION(
        "RAW_IMPORT_CONVERSION", "Raw import conversion started"), VI_UPDATE("VI_UPDATE",
        "Virtual machine template updated"), CONVERSION_FAILED("CONVERSION_FAILED",
        "Virtual machine template conversion failed"), CONVERSION_FINISHED("CONVERSION_FINISHED",
        "Virtual machine template conversion finished"), VI_PERSISTENT_MOVED("VI_PERSISTENT_MOVED",
        "Persistent virtual machine template moved"),

    // Persistent Process Events
    PERSISTENT_PROCESS_START("PERSISTENT_PROCESS_START",
        "A persistent conversion process has started"), PERSISTENT_RAW_FINISHED(
        "PERSISTENT_RAW_FINISHED",
        "A persistent RAW conversion has finished and it is ready to be dumped to a volume"), PERSISTENT_VOLUME_CREATED(
        "PERSISTENT_VOLUME_CREATED", "A persistent volume has been created"), PERSISTENT_DUMP_ENQUEUED(
        "PERSISTENT_DUMP_ENQUEUED", "A persistent volume dump has been queued"), PERSISTENT_DUMP_FINISHED(
        "PERSISTENT_DUMP_FINISHED", "A persistent dump to a volume has finished"), PERSISTENT_PROCESS_FINISHED(
        "PERSISTENT_PROCESS_FINISHED", "A persistent conversion process has finished"), PERSISTENT_PROCESS_FAILED(
        "PERSISTENT_PROCESS_FAILED", "A persistent process has failed"), PERSISTENT_INITIATOR_ADDED(
        "PERSISTENT_INITIATOR_ADDED", "Persistent initiator was added"),

    // License Events
    LICENSE_ADDED("LICENSE_ADDED", "A new license has been added to the system"), LICENSE_REMOVED(
        "LICENSE_REMOVED", "A license has been removed"), LICENSE_EXCEEDED("LICENSE_EXCEEDED",
        "Current license capabilities have been exceeded"),

    // Networking Events
    VLAN_CREATED("VLAN_CREATED", "New VLAN created"), VLAN_EDITED("VLAN_EDITED", "VLAN edited"), VLAN_DELETED(
        "VLAN_DELETED", "VLAN deleted"), NIC_ASSIGNED_VIRTUAL_MACHINE(
        "NIC_ASSIGNED_VIRTUAL_MACHINE", "NIC assigned to a virtual machine"), NIC_RELEASED_VIRTUAL_MACHINE(
        "NIC_RELEASED_VIRTUAL_MACHINE", "NIC released from a virtual machine"), PUBLIC_IP_ASSIGNED_VDC(
        "PUBLIC_IP_ASSIGNED_VDC", "Public IP assigned to a virtual datacenter"), PUBLIC_IP_RELEASED_VDC(
        "PUBLIC_IP_RELEASED_VDC", "Public IP released from a virtual datacenter"), UNDER_QUARANTINE(
        "IP_UNDER_QUARANTINE", "IP address put into quarantine"), RELEASED_QUARANTINE(
        "RELEASED_QUARANTINE", "IP address released from quarantine"), PRIVATE_IP_ASSIGN(
        "PRIVATE_IP_ASSIGN", "Private IP assigned"), PRIVATE_IP_UNASSIGN("PRIVATE_IP_UNASSIGN",
        "Private IP unassigned"), PUBLIC_IP_ASSIGN("PUBLIC_IP_ASSIGN", "Public IP assigned"), PUBLIC_IP_UNASSIGN(
        "PUBLIC_IP_UNASSIGN", "Public IP released"), NETWORK_CONFIGURATION_UPDATED(
        "NETWORK_CONFIGURATION_UPDATED", "Virtual machine network configuration updated"), EXTERNAL_IP_ASSIGN(
        "EXTERNAL_IP_ASSIGN", "External IP assigned"), EXTERNAL_IP_UNASSIGN("EXTERNAL_IP_UNASSIGN",
        "External IP released"), NIC_REORDER_VIRTUAL_MACHINE("NIC_REORDER_VIRTUAL_MACHINE",
        "Virtual machine NICs reordered"), VLAN_DEFAULT("VLAN_DEFAULT", "VLAN set as default"), VLAN_DEFAULT_ENTERPRISE(
        "VLAN_DEFAULT_ENTERPRISE", "Default enterprise VLAN changed"),

    // Workload Engine Events
    WORKLOAD_LOAD_RULES("WORKLOAD_LOAD_RULES", "Load workload rules"), WORKLOAD_APPLY_RULES(
        "WORKLOAD_APPLY_RULES", "Apply workload rules"), WORKLOAD_SOFT_LIMIT_EXCEEDED(
        "SOFT_LIMIT_EXCEEDED", "Soft limits exceeded"), WORKLOAD_HARD_LIMIT_EXCEEDED(
        "HARD_LIMIT_EXCEEDED", "Hard limits exceeded"),

    // Client Events
    THEME_UPDATE("THEME_UPDATE", "Theme updated"), UPDATE_PROPERTIES("UPDATE_PROPERTIES",
        "Client properties updated"),

    // Role Events
    ROLE_CREATED("ROLE_CREATED", "Role created"), ROLE_MODIFY("ROLE_MODIFIED", "Role updated"), ROLE_DELETED(
        "ROLE_DELETED", "Role deleted"), ROLE_PRIVILEGES_MODIFY("ROLE_PRIVILEGES_MODIFY",
        "Role's privileges modified"),

    // RoleLdap Events
    ROLE_LDAP_CREATED("ROLE_LDAP_CREATED", "LDAP role created"), ROLE_LDAP_MODIFY(
        "ROLE_LDAP_MODIFIED", "LDAP role updated"), ROLE_LDAP_DELETED("ROLE_LDAP_DELETED",
        "LDAP role deleted"),

    // HA Engine Events
    MACHINE_DISABLED_BY_HA("MACHINE_DISABLED_BY_HA", "Machine disabled by HA engine"), VAPP_BLOCKED_BY_HA(
        "VAPP_BLOCKED_BY_HA", "Virtual appliance blocked by HA engine"), VM_MOVING_BY_HA(
        "VM_MOVING_BY_HA", "Virtual machine being moved by HA engine"),

    // Allocation Rule Events
    ALLOCATION_RULES_APPLIED("ALLOCATION_RULES_APPLIED", "Allocation rules applied"), ALLOCATION_RULES_REMOVED(
        "ALLOCATION_RULE_REMOVED", "Allocation rule removed"),

    // Pricing Template Events
    PRICING_TEMPLATE_CREATED("PRICING_TEMPLATE_CREATED", "Pricing template created"), PRICING_TEMPLATE_MODIFIED(
        "PRICING_TEMPLATE_MODIFIED", "Pricing template updated"), PRICING_TEMPLATE_DELETED(
        "PRICING_TEMPLATE_DELETED", "Pricing template deleted"), PRICING_TEMPLATE_ASSIGNED(
        "PRICING_TEMPLATE_ASSIGNED", "Pricing template assigned"),

    // Cost Code-Currency Events
    COSTCODE_CURRENCY_CREATED("COSTCODE_CURRENCY_CREATED", "Cost code -currency created"), COSTCODE_CURRENCY_MODIFIED(
        "COSTCODE_CURRENCY_MODIFIED", "Cost code -currency updated"), COSTCODE_CURRENCY_DELETED(
        "COSTCODE_CURRENCY_DELETED", "Cost code -currency deleted"),

    // Cost Code Events
    COSTCODE_CREATED("COSTCODE_CREATED", "Cost code created"), COSTCODE_MODIFIED(
        "COSTCODE_MODIFIED", "Cost code updated"), COSTCODE_DELETED("COSTCODE_DELETED",
        "Cost code deleted"),

    // Currency Events
    CURRENCY_CREATED("CURRENCY_CREATED", "Currency created"), CURRENCY_MODIFIED(
        "CURRENCY_MODIFIED", "Currency updated"), CURRENCY_DELETED("CURRENCY_DELETED",
        "Currency deleted"),

    // Storage Device Events
    STORAGE_DEVICE_CREATED("STORAGE DEVICE CREATED", "Storage device created"), STORAGE_DEVICE_MODIFIED(
        "STORAGE DEVICE MODIFIED", "Storage device modified"), STORAGE_DEVICE_DELETED(
        "STORAGE DEVICE DELETED", "Storage device deleted"),

    // Chef Events
    CHEF_RUNLIST_DELETE("CHEF_RUNLIST_DELETE", "Remove an element from the runlist"), CHEF_NODE_UPDATE(
        "CHEF_NODE_UPDATE", "Update a Chef node"), CHEF_RUNLIST_UPDATE("CHEF_RUNLIST_UPDATE",
        "Update Chef runlist"), CHEF_CONNECTION("CHEF_SERVER_CONNECT", "Connect to Chef server"),

    // Template Category Events
    CATEGORY_CREATED("CATEGORY CREATED", "Category created"), CATEGORY_MODIFIED(
        "CATEGORY MODIFIED", "Category modified"), CATEGORY_DELETED("CATEGORY DELETED",
        "Category deleted"),

    // OVF Package List Events
    OVF_PACKAGES_LIST_CREATED("OVFPACKAGE LIST CREATED", "OVFPackage list created"), TEMPLATE_DEFINITION_LIST_DELETED(
        "OVFPACKAGE LIST DELETED", "OVFPackage list deleted"), TEMPLATE_DEFINITION_LIST_MODIFIED(
        "OVFPACKAGE LIST MODIFIED", "OVFPackage list modified"),

    // Instance Process Events
    INSTANCE_PROCESS_START("INSTANCE_PROCESS_START", "An instance conversion process has started"), INSTANCE_PROCESS_FINISHED(
        "INSTANCE_PROCESS_FINISHED", "An instance conversion process has finished successfully"), INSTANCE_PROCESS_FAILED(
        "INSTANCE_PROCESS_FAILED", "An instance conversion process has failed"),

    // Asynchronous Handler Events
    ASYNC_HANDLER_RESPONSE("ASYNC_HANDLER_RESPONSE", "Asynchronous hander response"),

    // UCS Events
    UCS_COMMUNICATION(
        "UCS_COMMUNICATION_PROBLEM",
        "There is a problem accessing the UCS. This might be due to several causes. Check UCS is working and reachable, and UCS credentials"), UCS_ASSOCIATE(
        "UCS_BLADE_ASSOCIATION", "Blade associated with a Service Profile in UCS"), UCS_DISASSOCIATE(
        "UCS_DISASSOCIATE", "Removed blade's association with UCS Service Profile"), UCS_DELETED(
        "SERVICE_PROFILE_DELETED", "Service Profile deleted in UCS"), UCS_BLADE_POWEROFF(
        "UCS_BLADE_POWER_OFF", "Blade powered off in UCS"), UCS_BLADE_POWERON("UCS_BLADE_POWER_ON",
        "Blade powered on in UCS"),

    // Scope Events
    SCOPE_CREATED("SCOPE_CREATED", "Scope created"), SCOPE_MODIFIED("SCOPE_MODIFIED",
        "Scope updated"), SCOPE_DELETED("SCOPE_DELETED", "Scope removed"),

    // Network Service Type events
    NST_CREATED("NST_CREATED", "Network service type created"), NST_UPDATED("NST_EDITED",
        "Network service type modified"), NST_DELETED("NST_DELETED", "Network service type deleted"),

    // Allowed Tiers
    TIER_ALLOWED("TIER_ALLOWED", "Storage tier allowed for use by an enterprise"), TIER_RESTRICTED(
        "TIER_RESTRICTED", "Storage tier restricted for an enterprise")

    ;

    private final String description;

    private final String long_description;

    private EventType(final String description, final String longDescription)
    {
        this.description = description;
        this.long_description = longDescription;
    }

    public String getDescription()
    {
        return description;
    }

    public String getLongDescription()
    {
        return this.long_description;
    }

    /**
     * Create a small main process to print the events in wiki mark-up style.
     * 
     * @param args
     */
    public static void main(final String[] args)
    {
        EventType[] events = EventType.values();
        Arrays.sort(events, new Comparator<EventType>()
        {
            @Override
            public int compare(final EventType ev1, final EventType ev2)
            {
                return ev1.ordinal() - ev2.ordinal();
            }

        });

        // Outputs all errors in wiki table format
        System.out.println("|| Action performed || Description || ");
        for (EventType error : events)
        {
            System.out.println(String.format("| %s | %s |", error.name(),
                error.getLongDescription()));
        }
    }
}
