/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.appslibrary;

import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

import com.abiquo.model.enumerator.DiskFormatTypeAlias;
import com.abiquo.model.transport.SingleResourceTransportDto;

@XmlRootElement(name = "diskformtattype")
@XmlType(propOrder = {"id", "uri", "description", "alias"})
public class DiskFormatTypeDto extends SingleResourceTransportDto
{
    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.diskformattype+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    private String uri, description;

    private DiskFormatTypeAlias alias;

    private static final long serialVersionUID = 1L;

    private Integer id;

    /**
     * Identifier of the entity
     * 
     * @Output
     * @return Identifier of the entity
     */
    public Integer getId()
    {
        return id;
    }

    public void setId(final Integer Id)
    {
        id = Id;
    }

    /**
     * URI of the Disk Format type
     * 
     * @Output
     * @return URI of the Disk Format type
     */
    public String getUri()
    {
        return uri;
    }

    public void setUri(final String Uri)
    {
        uri = Uri;
    }

    /**
     * Description of the type
     * 
     * @Output
     * @return Description of the type
     */
    public String getDescription()
    {
        return description;
    }

    public void setDescription(final String Description)
    {
        description = Description;
    }

    /**
     * Alias of the disk format type
     * 
     * @Output
     * @return Alias of the disk format type
     */
    public DiskFormatTypeAlias getAlias()
    {
        return alias;
    }

    public void setAlias(final DiskFormatTypeAlias Alias)
    {
        alias = Alias;
    }

    @Override
    public String getMediaType()
    {
        return DiskFormatTypeDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }
}
