/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.appslibrary;

import java.util.ArrayList;
import java.util.List;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.transport.WrapperDto;

/**
 * Wrapper class anotation for class {@link VirtualMachineTemplateDto} object
 */
@XmlRootElement(name = "virtualMachineTemplates")
public class VirtualMachineTemplatesDto extends WrapperDto<VirtualMachineTemplateDto>
{
    private static final long serialVersionUID = -7866288939970057395L;

    public static final String BASE_MEDIA_TYPE =
        "application/vnd.abiquo.virtualmachinetemplates+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    /**
     * List of virtual machine templates
     * 
     * @output
     */
    @Override
    @XmlElement(name = "virtualMachineTemplate")
    public List<VirtualMachineTemplateDto> getCollection()
    {
        if (collection == null)
        {
            collection = new ArrayList<VirtualMachineTemplateDto>();
        }
        return collection;
    }

    @Override
    public String getMediaType()
    {
        return VirtualMachineTemplatesDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return VirtualMachineTemplatesDto.BASE_MEDIA_TYPE;
    }
}
