/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.cloud;

import javax.validation.constraints.NotNull;
import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.enumerator.HypervisorType;
import com.abiquo.model.transport.SingleResourceTransportDto;

@XmlRootElement(name = "hypervisor")
public class HypervisorDiscoveryDto extends SingleResourceTransportDto
{

    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.hypervisordiscovery+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    private Integer port;

    private String ipFrom;

    private String ipTo;

    private HypervisorType type;

    private String user;

    private String password;

    private String vSwitch;

   /**
    * Hypervisor port
    * 
    * @return
    */
    @NotNull
    public Integer getPort()
    {
        return port;
    }

    public void setPort(Integer port)
    {
        this.port = port;
    }

    /**
     * Starting IP
     * 
     * @return
     */
    @NotNull
    public String getIpFrom()
    {
        return ipFrom;
    }

    public void setIpFrom(String ipFrom)
    {
        this.ipFrom = ipFrom;
    }

    /**
     * Ending IP
     * 
     * @return
     */
    @NotNull
    public String getIpTo()
    {
        return ipTo;
    }

    public void setIpTo(String ipTo)
    {
        this.ipTo = ipTo;
    }

    /**
     * Hypervisor type
     * 
     * @return
     */
    @NotNull
    public HypervisorType getType()
    {
        return type;
    }

    public void setType(HypervisorType type)
    {
        this.type = type;
    }

    /**
     * Hypervisor credentials
     * 
     * @return
     */
    @NotNull
    public String getUser()
    {
        return user;
    }

    public void setUser(String user)
    {
        this.user = user;
    }

    /**
     * Hypervisor password
     * 
     * @return
     */
    @NotNull
    public String getPassword()
    {
        return password;
    }

    public void setPassword(String password)
    {
        this.password = password;
    }

    /**
     * VSwitch
     * 
     * @return
     */
    @NotNull
    public String getvSwitch()
    {
        return vSwitch;
    }

    public void setvSwitch(String vSwitch)
    {
        this.vSwitch = vSwitch;
    }

    @Override
    public String getMediaType()
    {
        return HypervisorDiscoveryDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }

}
