/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.cloud;

import java.util.ArrayList;
import java.util.List;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.enumerator.HypervisorType;
import com.abiquo.model.transport.WrapperDto;

/**
 * Represent a collection of HypervisorTypes
 */
@XmlRootElement(name = "hypervisorstype")
public class HypervisorTypesDto extends WrapperDto<HypervisorTypeDto>
{
    /**
     * 
     */
    private static final long serialVersionUID = -4460166562066326383L;

    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.hypervisortypes+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

   /**
    * List of hypervisor types
    */
    @Override
    @XmlElement(name = "hypervisortype")
    public List<HypervisorTypeDto> getCollection()
    {
        return collection;
    }

    public void setCollection(final ArrayList<HypervisorType> arrayList)
    {
        // TODO Auto-generated method stub

        for (HypervisorType ht : arrayList)
        {
            HypervisorTypeDto aux = new HypervisorTypeDto();
            aux.setBaseFormat(ht.baseFormat);
            aux.setCompatibilityTable(ht.compatibilityTable);
            aux.setDefaultPort(ht.defaultPort);
            aux.setId(ht.id());
            collection.add(aux);
        }

    }

    @Override
    public String getMediaType()
    {
        return HypervisorTypesDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }
}
