/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.cloud;

import java.io.Serializable;

import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

import com.abiquo.model.transport.SingleResourceTransportDto;

/**
 * DTO to modify state parameters of the appliance.
 * 
 * @author ssedano
 */
@XmlRootElement(name = "virtualApplianceState")
@XmlType(propOrder = {"power"})
public class VirtualApplianceStateDto extends SingleResourceTransportDto implements Serializable
{

    /**
     * 
     */
    private static final long serialVersionUID = 7891496375111061310L;

    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.virtualappliancestate+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    /**
     * Machine power state. <br>
     * Values
     * <ul>
     * <li><b>DEPLOYED</b></li>
     * <li><b>NOT_DEPLOYED</b></li>
     * <li><b>NEEDS_SYNCHRONIZE</b></li>
     * </ul>
     */
    private VirtualApplianceState power;

    /**
     * Machine power state. Current state of the virtual appliance. The state is inferred from its
     * virtual machines
     * 
     * @output
     * @return <ul>
     *         <li><b>DEPLOYED</b></li>
     *         <li><b>NOT_DEPLOYED</b></li>
     *         <li><b>NEEDS_SYNCHRONIZE</b></li>
     *         </ul>
     */
    public VirtualApplianceState getPower()
    {
        return power;
    }

    /**
     * Machine power state. <br>
     * Values
     * <ul>
     * <li><b>DEPLOYED</b></li>
     * <li><b>NOT_DEPLOYED</b></li>
     * <li><b>NEEDS_SYNCHRONIZE</b></li>
     * </ul>
     * 
     * @param power <ul>
     *            <li><b>DEPLOYED</b></li>
     *            <li><b>NOT_DEPLOYED</b></li>
     *            <li><b>NEEDS_SYNCHRONIZE</b></li>
     *            </ul>
     *            void
     */
    public void setPower(final VirtualApplianceState power)
    {
        this.power = power;
    }

    @Override
    public String getMediaType()
    {
        return VirtualApplianceStateDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }
}
