/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.cloud;

import java.io.Serializable;

import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.transport.SingleResourceTransportDto;

/**
 * DTO to deploy parameters of the virtual machine.
 * 
 * @author ssedano
 */
@XmlRootElement(name = "virtualmachinetask")
public class VirtualMachineTaskDto extends SingleResourceTransportDto implements Serializable
{

    /**
     * 
     */
    private static final long serialVersionUID = -272879466628574960L;

    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.virtualmachinetask+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    /**
     * Force the soft limits defined for the enterprise in the deploy. <br>
     * Values
     * <ul>
     * <li><b>false</b></li>
     * <li><b>true</b></li>
     * </ul>
     */
    private Boolean forceEnterpriseSoftLimits;

    /**
     * Imported machines does not have the image stored in an Abiquo repo. If we undpeloy them, we
     * have lost the image and it is unrecoverable. Use it if you force to undeploy imported
     * VirtualMachines.
     */
    private Boolean forceUndeploy;

    /**
     * Force the soft limits defined for the enterprise in the deploy. <br>
     * Values
     * <ul>
     * <li><b>false</b></li>
     * <li><b>true</b></li>
     * </ul>
     * 
     * @return <ul>
     *         <li><b>false</b></li>
     *         <li><b>true</b></li>
     *         </ul>
     */
    public Boolean isForceEnterpriseSoftLimits()
    {
        return forceEnterpriseSoftLimits == null ? false : forceEnterpriseSoftLimits;
    }

    /**
     * Force the soft limits defined for the enterprise in the deploy. <br>
     * Values
     * <ul>
     * <li><b>OFF</b></li>
     * <li><b>ON</b></li>
     * </ul>
     * 
     * @param power <ul>
     *            <li><b>OFF</b></li>
     *            <li><b>ON</b></li>
     *            </ul>
     *            void
     */
    public void setForceEnterpriseSoftLimits(final Boolean forceEnterpriseSoftLimits)
    {
        this.forceEnterpriseSoftLimits = forceEnterpriseSoftLimits;
    }

    /**
     * @param forceUndeploy
     */
    public void setForceUndeploy(final Boolean forceUndeploy)
    {
        this.forceUndeploy = forceUndeploy;
    }

    /**
     * Imported machines does not have the image stored in an Abiquo repo. If we undpeloy them, we
     * have lost the image and it is unrecoverable. Use it if you force to undeploy imported
     * VirtualMachines.
     * 
     * @return force.
     */
    public Boolean getForceUndeploy()
    {
        return forceUndeploy;
    }

    @Override
    public String getMediaType()
    {
        return VirtualMachineTaskDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }

}
