/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.enterprise;

import javax.validation.constraints.NotNull;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

import com.abiquo.model.transport.SingleResourceWithLimitsDto;

@XmlRootElement(name = "limit")
@XmlType(propOrder = {"id", "repositoryHardLimitsInMb", "repositorySoftLimitsInMb"})
public class DatacenterLimitsDto extends SingleResourceWithLimitsDto
{
    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.limit+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    public static final String MEDIA_TYPE_22 = BASE_MEDIA_TYPE + "; version=" + API_VERSION_22;

    public static final String MEDIA_TYPE_23 = BASE_MEDIA_TYPE + "; version=" + API_VERSION_23;

    private Integer id;

    private long repositoryHardLimitsInMb;

    private long repositorySoftLimitsInMb;

    /**
     * Identifier of the limit
     * 
     * @Output
     * @return the id
     */
    public Integer getId()
    {
        return id;
    }

    public void setId(final Integer id)
    {
        this.id = id;
    }

    /**
     * Total size of repository space to be used. Soft limit
     * 
     * @return Total size of repository space to be used. Soft limit
     */
    @NotNull
    @XmlElement(name = "repositorySoft")
    public long getRepositorySoftLimitsInMb()
    {
        return repositorySoftLimitsInMb;
    }

    public void setRepositorySoftLimitsInMb(final long repositorySoftLimitsInMb)
    {
        this.repositorySoftLimitsInMb = repositorySoftLimitsInMb;
    }

    /**
     * Total size of repository space to be used. Hard limit
     * 
     * @return Total size of repository space to be used. Hard limit
     */
    @NotNull
    @XmlElement(name = "repositoryHard")
    public long getRepositoryHardLimitsInMb()
    {
        return repositoryHardLimitsInMb;
    }

    public void setRepositoryHardLimitsInMb(final long repositoryHardLimitsInMb)
    {
        this.repositoryHardLimitsInMb = repositoryHardLimitsInMb;
    }

    @Override
    public String getMediaType()
    {
        return DatacenterLimitsDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }

}
