/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.enterprise;

import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

/**
 * EnterpriseTheme entity offers Enterprise data plus information on associated custom theme
 * 
 * @author destevezg
 */
@XmlRootElement(name = "enterprisetheme")
@XmlType(propOrder = {"theme", "companyLogoPath"})
public class EnterpriseThemeDto extends EnterpriseDto
{

    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.enterprisetheme+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }

    @Override
    public String getMediaType()
    {
        return EnterpriseThemeDto.MEDIA_TYPE;
    }

    public void setTheme(final String theme)
    {
        this.theme = theme;
    }

    /**
     * Custom theme's name
     * 
     * @output
     */
    public String getTheme()
    {
        return theme;
    }

    public void setCompanyLogoPath(final String companyLogoPath)
    {
        this.companyLogoPath = companyLogoPath;
    }

    /**
     * Custom theme's logo path (image)
     * 
     * @output
     */
    public String getCompanyLogoPath()
    {
        return companyLogoPath;
    }

    private String theme;

    private String companyLogoPath;

}
