/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.infrastructure;

import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

@XmlRootElement(name = "reservedMachine")
@XmlType(propOrder = {"datacenter", "rack"})
public class ReservedMachineDto extends MachineDto
{

    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.reservedmachine+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    private DatacenterDto datacenter;

    private RackDto rack;

    public void setRack(final RackDto rack)
    {
        this.rack = rack;
    }

    /**
     * Rack of the physical machine
     */
    public RackDto getRack()
    {
        return rack;
    }

    public void setDatacenter(final DatacenterDto datacenter)
    {
        this.datacenter = datacenter;
    }

    /**
     * Datacenter of the physical machine
     */
    public DatacenterDto getDatacenter()
    {
        return datacenter;
    }

    @Override
    public String getMediaType()
    {
        return MachineDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }

}
