/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.infrastructure;

import javax.validation.constraints.NotNull;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

/**
 * The Class UcsRackDto.
 */
@XmlRootElement(name = "ucsrack")
@XmlType(propOrder = {"defaultTemplate", "ip", "maxMachinesOn", "password", "port", "user"})
public class UcsRackDto extends RackDto
{

    /** The Constant BASE_MEDIA_TYPE. */
    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.ucsrack+xml";

    /** The Constant MEDIA_TYPE. */
    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1L;

    /** The port. */
    private Integer port;

    /** The ip. */
    private String ip;

    /** The password. */
    private String password;

    /** The user. */
    private String user;

    /** The default template. */
    private String defaultTemplate;

    /** The max machines on. */
    private Integer maxMachinesOn;

    /*
     * (non-Javadoc)
     * @see com.abiquo.server.core.infrastructure.RackDto#getBaseMediaType()
     */
    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }

    /**
     * UCS default template to use.
     * 
     * @return the default template
     */
    public String getDefaultTemplate()
    {
        return this.defaultTemplate;
    }

    /**
     * IP Address of the UCS server.
     * 
     * @return the ip
     */
    @NotNull
    public String getIp()
    {
        return ip;
    }

    /**
     * Maximum number of machines in power on in UCS.
     * 
     * @return the max machines on
     */
    public Integer getMaxMachinesOn()
    {
        return maxMachinesOn;
    }

    /*
     * (non-Javadoc)
     * @see com.abiquo.server.core.infrastructure.RackDto#getMediaType()
     */
    @Override
    public String getMediaType()
    {
        return UcsRackDto.MEDIA_TYPE;
    }

    /**
     * Password to authenticate to UCS.
     * 
     * @return the password
     */
    @NotNull
    public String getPassword()
    {
        return password;
    }

    /**
     * Connection port to UCS.
     * 
     * @return the port
     */
    @NotNull
    public Integer getPort()
    {
        return port;
    }

    /**
     * User to log in into UCS.
     * 
     * @return the user
     */
    @NotNull
    public String getUser()
    {
        return user;
    }

    /**
     * Sets the default template.
     * 
     * @param defaultTemplate the new default template
     */
    public void setDefaultTemplate(final String defaultTemplate)
    {
        this.defaultTemplate = defaultTemplate;
    }

    /**
     * Sets the ip.
     * 
     * @param ip the new ip
     */
    public void setIp(final String ip)
    {
        this.ip = ip;
    }

    /**
     * Sets the max machines on.
     * 
     * @param maxMachinesOn the new max machines on
     */
    public void setMaxMachinesOn(final Integer maxMachinesOn)
    {
        this.maxMachinesOn = maxMachinesOn;
    }

    /**
     * Sets the password.
     * 
     * @param password the new password
     */
    public void setPassword(final String password)
    {
        this.password = password;
    }

    /**
     * Sets the port.
     * 
     * @param port the new port
     */
    public void setPort(final Integer port)
    {
        this.port = port;
    }

    /**
     * Sets the user.
     * 
     * @param user the new user
     */
    public void setUser(final String user)
    {
        this.user = user;
    }
}
