/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.infrastructure.network;

import javax.validation.constraints.NotNull;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

import com.abiquo.model.transport.SingleResourceTransportDto;

/**
 * Defines a kind of network. This entity establishes the relation between the available VLANs where
 * the Virtual Machines can be connected and all the available physical Network Interfaces of the
 * Hypervisors.
 * 
 * @author jaume
 */
@XmlRootElement(name = "networkservicetype")
@XmlType(propOrder = {"id", "name", "defaultNST"})
public class NetworkServiceTypeDto extends SingleResourceTransportDto
{
    private static final long serialVersionUID = 1L;

    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.networkservicetype+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    private Integer id;

    /**
     * Identifier of the entity
     * 
     * @output
     */
    public Integer getId()
    {
        return id;
    }

    public void setId(final Integer id)
    {
        this.id = id;
    }

    private String name;

    /**
     * Name that defines the Network Service Type.
     */
    @NotNull
    public String getName()
    {
        return name;
    }

    public void setName(final String name)
    {
        this.name = name;
    }

    private boolean defaultNST;

    /**
     * Whenever the Network Service Type is the default one by the current datacenter
     * 
     * @output
     */
    public boolean isDefaultNST()
    {
        return defaultNST;
    }

    public void setDefaultNST(final boolean defaultNST)
    {
        this.defaultNST = defaultNST;
    }

    @Override
    public String getMediaType()
    {
        return MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }

}
