/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.infrastructure.storage;

import javax.validation.constraints.NotNull;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

import com.abiquo.model.transport.SingleResourceTransportDto;

/* 
 * @restlink <link rel="tier" href="example.com/api/admin/datacenters/{id}/tiers/{id}"/>
 */
@XmlRootElement(name = "storagePool")
@XmlType(propOrder = {"idStorage", "name", "totalSizeInMb", "usedSizeInMb", "availableSizeInMb",
"enabled"})
public class StoragePoolDto extends SingleResourceTransportDto
{

    private static final long serialVersionUID = 1L;

    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.storagepool+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    protected String idStorage;

    /**
     * Identifier of the entity.
     */
    public String getIdStorage()
    {
        return idStorage;
    }

    public void setIdStorage(final String idStorage)
    {
        this.idStorage = idStorage;
    }

    protected String name;

    /**
     * Name of the storage pool.
     */
    @NotNull
    public String getName()
    {
        return name;
    }

    public void setName(final String name)
    {
        this.name = name;
    }

    protected long totalSizeInMb;

    /**
     * Total size in MB of the storage pool.
     */
    @NotNull
    public long getTotalSizeInMb()
    {
        return totalSizeInMb;
    }

    public void setTotalSizeInMb(final long totalSizeInMb)
    {
        this.totalSizeInMb = totalSizeInMb;
    }

    protected long usedSizeInMb;

    /**
     * Used size in MB of the storage pool.
     */
    @NotNull
    public long getUsedSizeInMb()
    {
        return usedSizeInMb;
    }

    public void setUsedSizeInMb(final long usedSizeInMb)
    {
        this.usedSizeInMb = usedSizeInMb;
    }

    protected long availableSizeInMb;

    /**
     * Available size in MB of the storage pool.
     */
    @NotNull
    public long getAvailableSizeInMb()
    {
        return availableSizeInMb;
    }

    public void setAvailableSizeInMb(final long availableSizeInMb)
    {
        this.availableSizeInMb = availableSizeInMb;
    }

    protected boolean enabled;

    /**
     * Returns true if the storage pool is enabled, false otherwise.
     * 
     * @output
     */
    public boolean getEnabled()
    {
        return enabled;
    }

    public void setEnabled(final boolean enabled)
    {
        this.enabled = enabled;
    }

    @Override
    public String getMediaType()
    {
        return StoragePoolDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }

}
