/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.infrastructure.storage;

import java.util.ArrayList;
import java.util.List;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import com.abiquo.model.transport.WrapperDto;

/**
 * Represent a collection of pools.
 * 
 * @restlink <link rel="tier" href="example.com/api/admin/datacenters/{id}/tiers/{id}"/>
 */
@XmlRootElement(name = "storagePools")
public class StoragePoolsDto extends WrapperDto<StoragePoolDto>
{
    private static final long serialVersionUID = 1L;

    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.storagepools+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    @Override
    @XmlElement(name = "storagePool")
    public List<StoragePoolDto> getCollection()
    {
        if (collection == null)
        {
            collection = new ArrayList<StoragePoolDto>();
        }
        return collection;
    }

    @Override
    public String getMediaType()
    {
        return StoragePoolsDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }
}
