/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.scheduler;

import javax.validation.constraints.NotNull;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

import com.abiquo.model.enumerator.FitPolicy;
import com.abiquo.model.transport.SingleResourceTransportDto;

/**
 * @restlink <link rel="datacenter" href="http://example.com/api/admin/datacenters/{datacenterId}/"
 *           />
 */
@XmlRootElement(name = "fitPolicyRule")
@XmlType(propOrder = {"id", "fitPolicy"})
public class FitPolicyRuleDto extends SingleResourceTransportDto
{
    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.fitpolicyrule+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    private Integer id;

    /**
     * Identifier of the entity
     */
    public Integer getId()
    {
        return id;
    }

    public void setId(final Integer id)
    {
        this.id = id;
    }

    private FitPolicy fitPolicy;

    @NotNull
    /**
     * Fit Policy possible values : PERFORMANCE or PROGRESSIVE"
     */
    public FitPolicy getFitPolicy()
    {
        return fitPolicy;
    }

    public void setFitPolicy(final FitPolicy fitPolicy)
    {
        this.fitPolicy = fitPolicy;
    }

    @Override
    public String getMediaType()
    {
        return FitPolicyRuleDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }

}
