/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.scheduler;

import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

import com.abiquo.model.transport.SingleResourceTransportDto;

/**
 * @restlink <link rel="datacenter" href= "http://localhost/api/admin/datacenters/{datacenterId}" />
 * @restlink <link rel="rack" href=
 *           "http://localhost/api/admin/datacenters/{datacenterId}/racks/{rackId}" />
 * @restlink <link rel="machine" href=
 *           "http://localhost/api/admin/datacenters/{datacenterId}/racks/{rackId}/machines/{machineId}"
 *           />
 */
@XmlRootElement(name = "machineLoadRule")
@XmlType(propOrder = {"id", "cpuLoadPercentage", "ramLoadPercentage"})
public class MachineLoadRuleDto extends SingleResourceTransportDto
{
    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.machineloadrule+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    private Integer id;

    /**
     * Identifier of the entity
     */
    public Integer getId()
    {
        return id;
    }

    public void setId(final Integer id)
    {
        this.id = id;
    }

    private Integer cpuLoadPercentage;

    /**
     * cpu percentage
     */
    public Integer getCpuLoadPercentage()
    {
        return cpuLoadPercentage;
    }

    public void setCpuLoadPercentage(final Integer cpuLoadPercentage)
    {
        this.cpuLoadPercentage = cpuLoadPercentage;
    }

    private Integer ramLoadPercentage;

    /**
     * ram percentage
     */
    public Integer getRamLoadPercentage()
    {
        return ramLoadPercentage;
    }

    public void setRamLoadPercentage(final Integer ramLoadPercentage)
    {
        this.ramLoadPercentage = ramLoadPercentage;
    }

    @Override
    public String getMediaType()
    {
        return MachineLoadRuleDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return BASE_MEDIA_TYPE;
    }
}
