/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.abiquo.server.core.task;

import java.util.HashMap;
import java.util.Map;

import com.abiquo.model.redis.RedisEntityBase;
import com.abiquo.model.redis.RedisEntityUtils;

public class Job extends RedisEntityBase
{
    public enum JobState
    {
        PENDING, STARTED, DONE, FAILED, SKIPPED, ROLLBACK_STARTED, ROLLBACK_DONE, UNKNOWN
    };

    public enum JobType
    {
        // Tarantino
        CONFIGURE, DECONFIGURE, RECONFIGURE, POWER_ON, POWER_OFF, PAUSE, RESUME, RESET, INSTANCE, REFRESH,

        // Template
        DOWNLOAD, PROMOTE,

        // Conversion manager
        DISK_CONVERSION, DUMP_DISK_TO_VOLUME, DUMP_VOLUME_TO_DISK,

        // Scheduler
        SCHEDULE, FREE_RESOURCES, UPDATE_RESOURCES;
    }

    protected String id;

    protected JobType type;

    protected JobState state;

    protected JobState rollbackState;

    protected String description;

    protected String parentTaskId;

    protected Long creationTimestamp;

    protected long timestamp;

    protected Map<String, String> data;

    public Job()
    {
        this.data = new HashMap<String, String>();
        this.state = JobState.PENDING;
        this.rollbackState = JobState.UNKNOWN;
        this.description = "";
        this.creationTimestamp = RedisEntityUtils.getUnixtime();
    }

    @Override
    protected String getIdAsString()
    {
        return getId();
    }

    public String getId()
    {
        return id;
    }

    public void setId(final String id)
    {
        this.id = id;
    }

    public JobType getType()
    {
        return type;
    }

    public void setType(final JobType type)
    {
        this.type = type;
    }

    public JobState getState()
    {
        return state;
    }

    public void setState(final JobState state)
    {
        this.state = state;
    }

    public JobState getRollbackState()
    {
        return rollbackState;
    }

    public void setRollbackState(final JobState rollbackState)
    {
        this.rollbackState = rollbackState;
    }

    public String getDescription()
    {
        return description;
    }

    public void setDescription(final String description)
    {
        this.description = description;
    }

    public Map<String, String> getData()
    {
        return this.data;
    }

    public long getTimestamp()
    {
        return timestamp;
    }

    public void setTimestamp(final long timestamp)
    {
        this.timestamp = timestamp;
    }

    public Long getCreationTimestamp()
    {
        return creationTimestamp;
    }

    public void setCreationTimestamp(final Long creationTimestamp)
    {
        this.creationTimestamp = creationTimestamp;
    }

    public String getParentTaskId()
    {
        return parentTaskId;
    }

    public void setParentTaskId(final String parentTaskId)
    {
        this.parentTaskId = parentTaskId;
    }

    @Override
    public String toString()
    {
        return String.format(
            "Job id: '%s' Job type: '%s' Task id: '%s' State: '%s' Rollback state: '%s'", getId(),
            getType().name(), getParentTaskId(), getState().name(), getRollbackState().name());
    }
}
