/**
 * Licensed to Abiquo Holdings S.L. (Abiquo) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package com.abiquo.server.core.task;

import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

@XmlRootElement(name = "taskextended")
@XmlType(propOrder = {"jobsExtended"})
public class TaskExtendedDto extends TaskDto
{
    private static final long serialVersionUID = -5807120086279168256L;

    public static final String BASE_MEDIA_TYPE = "application/vnd.abiquo.taskextended+xml";

    public static final String MEDIA_TYPE = BASE_MEDIA_TYPE + "; version=" + API_VERSION;

    private JobsExtendedDto jobsExtended;

    public TaskExtendedDto()
    {
    }

    /**
     * do not initialize Jobs
     */
    public TaskExtendedDto(final TaskDto task)
    {
        setTaskId(task.getTaskId());
        setOwnerId(task.getOwnerId());
        setUserId(task.getUserId());
        setType(task.getType());
        setState(task.getState());
        setTimestamp(task.getTimestamp());
        setLinks(task.getLinks());
    }

    /**
     * Extended jobs collection of the task
     * 
     * @output
     */
    public JobsExtendedDto getJobsExtended()
    {
        return jobsExtended;
    }

    public void setJobsExtended(final JobsExtendedDto jobsExtended)
    {
        this.jobsExtended = jobsExtended;
    }

    @Override
    public String getMediaType()
    {
        return TaskExtendedDto.MEDIA_TYPE;
    }

    @Override
    public String getBaseMediaType()
    {
        return TaskExtendedDto.BASE_MEDIA_TYPE;
    }
}
